
# Type: physically interacts with


holds between two entities that make physical contact as part of some interaction

URI: [biolink:physically_interacts_with](https://w3id.org/biolink/vocab/physically_interacts_with)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [interacts with](interacts_with.md)

## Children

 *  [molecularly interacts with](molecularly_interacts_with.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | WD:P129 |
|  | | SEMMEDDB:INTERACTS_WITH |
| **In Subsets:** | | translator_minimal |

